=======
Credits
=======

Development Lead
----------------

* Guilherme Castelao <guilherme@castelao.net>

Contributors
------------

Erdem M Karakoylu: Reported bad checksum on CARS' salinity file (issue #7).
@sgartzman: Reported bug #8, truncated files on Python-2.
@maryjacketti: Reported bug #12, outdated ETOPO documentation.
Uday Bhaskar T V S: Reported improper path to DB files for Windows machines.
Carin Anderson & Ozan Göktürk: Reported bug #14 - coordinates partially coincident.
